@@ -14,11 +14,8 @@
 #'  \item{\link[=plot.see_p_direction]{bayestestR::p_direction()}}
 #'  \item{\link[=plot.see_p_significance]{bayestestR::p_significance()}}
 #'  \item{\link[=plot.see_si]{bayestestR::si()}}
-#'  \item{\link[=plot.see_easycormatrix]{correlation::correlation()}}
-#'  \item{\link[=plot.see_easycorrelation]{correlation::correlation()} (Gaussian Graphical Models)}
 #'  \item{\link[=plot.see_effectsize_table]{effectsize::effectsize()}}
 #'  \item{\link[=plot.see_estimate_contrasts]{modelbased::estimate_contrasts()}}
-#'  \item{\link[=plot.see_cluster_analysis]{parameters::cluster_analysis()}}
 #'  \item{\link[=plot.see_compare_parameters]{parameters::compare_parameters()}}
 #'  \item{\link[=plot.see_parameters_distribution]{parameters::describe_distribution()}}
 #'  \item{\link[=plot.see_parameters_model]{parameters::model_parameters()}}
@@ -133,16 +130,16 @@ data_plot <- function(x, data = NULL, ...) {
 #' @export
 add_plot_attributes <- function(x) {
   info <- attributes(x)$info
-  out <- list(ylab(info$ylab), xlab(info$xlab))
+  out <- list(ggplot2::ylab(info$ylab), ggplot2::xlab(info$xlab))
 
   if (!is.null(info$legend_fill)) {
-    out[[length(out) + 1]] <- labs(fill = info$legend_fill)
+    out[[length(out) + 1]] <- ggplot2::labs(fill = info$legend_fill)
   }
   if (!is.null(info$legend_color)) {
-    out[[length(out) + 1]] <- labs(color = info$legend_color)
+    out[[length(out) + 1]] <- ggplot2::labs(color = info$legend_color)
   }
   if (!is.null(info$title)) {
-    out[[length(out) + 1]] <- labs(title = info$title)
+    out[[length(out) + 1]] <- ggplot2::labs(title = info$title)
   }
 
   out
