@@ -4,7 +4,7 @@
 #'
 #' @inheritParams data_plot
 #' @inheritParams plot.see_bayesfactor_parameters
-#' @inheritParams plot.see_cluster_analysis
+#' @inheritParams plot.see_parameters_model
 #'
 #' @return A ggplot2-object.
 #'
@@ -138,6 +138,8 @@ plot.see_equivalence_test <- function(x,
   if (rope.line.alpha > 1) rope.line.alpha <- 1
 
 
+  insight::check_if_installed("ggridges")
+
   p <- ggplot(tmp, aes_string(x = "estimate", y = "predictor", fill = "grp")) +
     annotate(
       "rect",
@@ -280,6 +282,8 @@ plot.see_equivalence_test_df <- function(x,
 
   if (rope.line.alpha > 1) rope.line.alpha <- 1
 
+  insight::check_if_installed("ggridges")
+
   p <- ggplot(tmp, aes_string(x = "estimate", y = "predictor", fill = "grp")) +
     annotate(
       "rect",
